@@ -129,7 +129,16 @@ date_today_update_day(gpointer data)
   {
     desktop_plugin->current_day = date_day;
     gchar date_buf[256];
-    strftime(date_buf, 255, dgettext("hildon-libs", date_formats[desktop_plugin->date_format]), date_time);
+    if(desktop_plugin->date_format>11)
+    {
+      gchar* format_x = g_strdup_printf("%%A %s", dgettext("hildon-libs", "wdgt_va_date"));
+      strftime(date_buf, 255, format_x, date_time);
+      g_free(format_x);
+    }
+    else
+    {
+      strftime(date_buf, 255, dgettext("hildon-libs", date_formats[desktop_plugin->date_format]), date_time);
+    }
     if(desktop_plugin->today_string)
       g_free(desktop_plugin->today_string);
     desktop_plugin->today_string = g_strdup(date_buf);
@@ -204,6 +213,14 @@ _create_format_list(DateTodayPlugin* desktop_plugin)
 		       1, i,
 		       -1);
   }
+  gchar* format_x = g_strdup_printf("%%A %s", dgettext("hildon-libs", "wdgt_va_date"));
+  strftime(date_buf, 255, format_x, date_time);
+  g_free(format_x);
+  gtk_list_store_append(list_store, &iter);
+  gtk_list_store_set(list_store, &iter,
+		     0, date_buf,
+		     1, i,
+		     -1);
   return list_store;
 }
 
